class ReportComponentsController < ApplicationController
  model_data_store(ReportComponent, {create: true, read: true, update: true, delete: true, index: true}, {})
  protect_with(ReportComponent.name, ReportComponent.display_name, [RxModule::Authorization.verb('create', 'Create', :create, 'rx_reports', 'designer'),
                                                                    RxModule::Authorization.verb('read', 'Read', [:show, :index]),
                                                                    RxModule::Authorization.verb('update', 'Update', :update, 'rx_reports', 'designer'),
                                                                    RxModule::Authorization.verb('delete', 'Delete', :destroy, 'rx_reports', 'designer'),
  ])

  private

  def before_set_targets
    ReportComponent.joins(:report_target)
  end

  def before_sort(sort)
    if sort[:id] == 'report_target.name'
      sort[:id] = "report_targets.name"
    elsif sort[:id] == 'report_target.module_name'
      sort[:id] = "report_targets.module_name"
    end
    sort
  end

  def before_filter(filter)
    if filter[:id] == 'report_target.name'
      filter[:id] = "report_targets.name"
    elsif filter[:id] == 'report_target.module_name'
      filter[:id] = "report_targets.module_name"
    end
    filter[:id] += "::text"
    filter
  end

  # Never trust parameters from the scary internet, only allow the white list through.
  def model_params
    params.require(:report_component).permit(:name, :parameters, :desc, :report_target_id)
  end
end