class ReportTargetsController < ApplicationController
  model_data_store(ReportTarget, {read: true, index: true}, {})
  protect_with(nil, nil, [{id: 'run', name: 'Run', controller_methods: :run}])
  before_action :set_target, only: [:show, :update, :destroy, :run, :known_filter_vals]

  def run
    run_params = params.require('report_target').require('parameters').permit!.to_h # we defer parameter validation to the module generating the report
    cache_key = run_params.hash
    Rails.logger.debug { "Cache key #{cache_key}" }
    result = Rails.cache.fetch(cache_key, expires_in: 15.minutes) do
      Rails.logger.debug { 'Cache miss for report page' }
      @model.run(run_params)
    end
    Thread.new do
      existing_offset = run_params&.[](:pagination)&.[](:offset)
      existing_limit = run_params&.[](:pagination)&.[](:limit)
      if existing_limit && existing_offset
        Rails.logger.debug { "Pregenerating next page" }
        cloned_run_params = (run_params || {}).dup.merge({pagination: {offset: existing_offset + existing_limit}})
        cache_key = cloned_run_params.hash
        Rails.logger.debug { "Cache key #{cloned_run_params}" }
        Rails.cache.fetch(cache_key, expires_in: 15.minutes) do
          Rails.logger.debug { 'Cache miss for report page' }
          @model.run(cloned_run_params)
        end
      end
    end
    render json: result
  end

  def known_filter_vals
    column = params[:column].gsub('-', '.')
    render json: @model.known_filter_vals(column)
  end
end
