import * as React from 'react';
import {observer} from "mobx-react-lite";
import {PaginatedReportComponent} from "../../../stores/PaginatedReportComponent";
import {i18n, SelectField} from "@rx-suite/ui";
import {ReportTargetModel} from "../../../stores/ReportTargetStore";
import {t, Trans} from "@lingui/macro";
import {AutomaticReportModel} from "../../stores/AutomaticReportStore";
import {ReportComponentModel, ReportComponentStore} from "../../stores/ReportComponentStore";

type ReportComponentRunParamsProps = {
    report: AutomaticReportModel,
    column: string
};

export const AutomaticReportRunParam: React.FunctionComponent<ReportComponentRunParamsProps> = observer(({
                                                                                                             report,
                                                                                                             column
                                                                                                         }) => {
    const component = ReportComponentStore.get(report.viewModel.report_component_id) as ReportComponentModel | undefined;
    const [knownValues, setKnownValues] = React.useState<string[]>([]);
    const [loading, setLoading] = React.useState(false);
    React.useEffect(() => {
        let isSubscribed = true;
        if (component && component.viewModel.report_target && (knownValues.length === 0)) {
            setLoading(true);
            (component.viewModel.report_target as ReportTargetModel).runFilterOptions(column).then(values => {
                if (isSubscribed) {
                    setLoading(false);
                    setKnownValues(values);
                }
            });
        }
        return () => {
            isSubscribed = false;
        };
    }, [component, column, knownValues]);
    if(!component){
        return null;
    }
    const columnDefinition = component.getReturnDef(column);
    if (!columnDefinition) {
        return null;
    }

    const options = [...knownValues.map(v => ({
        label: v,
        value: v
    })), {
        label: i18n._(t`[Blank]`),
        value: ''
    }, ...(report.runFilterValue(column) || []).map(v => ({
        label: v,
        value: v
    }))];
    return <SelectField label={columnDefinition.name}
                        options={options}
                        name={column}
                        value={report.runFilterValue(column) || []}
                        onChange={report.handleRunFilterChange}
                        loading={loading}
                        hint={{
                            title: columnDefinition.name,
                            subtitle: i18n._(t`Run Filter`),
                            children: <div>
                                <div>{columnDefinition.desc}</div>
                                <Trans>You can add an option to the list by typing it, even if it doesn't show up in the
                                    dropdown.</Trans>
                            </div>
                        }}
                        multiple
                        creatable
                        clearable
    />
});