import * as React from 'react';
import {observer} from "mobx-react-lite";
import {AutomaticReportModel} from "../../stores/AutomaticReportStore";
import ChipInput from "material-ui-chip-input";
import {HintButton} from "@rx-suite/ui/build";
import {makeStyles} from "@material-ui/core/styles";

const useStyles = makeStyles(theme => ({
    fieldAndHint: {
        display: 'flex',
        alignItems: 'center',
        width: '100%'
    }
}));

export const MailToEmailsField: React.FunctionComponent<{ autoreport: AutomaticReportModel, readOnly?: boolean }> = observer(({autoreport, readOnly}) => {
    const classes = useStyles();
    return <div className={classes.fieldAndHint}>
        <ChipInput label={autoreport.label('mail_to_emails')}
                   value={autoreport.viewModel.mail_to_emails}
                   onAdd={(chip) => autoreport.nestedAssignment('mail_to_emails', [...autoreport.viewModel.mail_to_emails, chip])}
                   onDelete={(chip) => autoreport.nestedAssignment('mail_to_emails', autoreport.viewModel.mail_to_emails.filter(c => c !== chip))}

                   helperText={autoreport.emailErrorString}
                   FormHelperTextProps={{error: true}}
                   blurBehavior={'add'}
                   disabled={readOnly} readOnly={readOnly}
                   fullWidth/>
        <HintButton title={autoreport.label('mail_to_emails')}
                    text={autoreport.attributeDescription('mail_to_emails')}/>
    </div>
});

