import * as React from 'react';
import {observer} from 'mobx-react-lite';
import {HintButtonProps, SelectField, SelectFieldProps, useModelContext, useReadonlyContext} from '@rx-suite/ui';
import {ReportComponentStore} from "../../stores/ReportComponentStore";
import {ReportTargetModel} from "../../stores/ReportTargetStore";
import {AutomaticReportModel} from "../../stores/AutomaticReportStore";

type Option = { label: string, value: string };
type Group = { label: string, options: Option[] };

type ReportSelectFieldProps =  Omit<SelectFieldProps, 'value' | 'onChange' | 'options'>

export const ReportSelectField: React.FunctionComponent<ReportSelectFieldProps> = observer(({label, disabled, ...props}) => {
    const readOnly = useReadonlyContext();
    const model = useModelContext() as AutomaticReportModel;
    const resolvedLabel = label || model.label('report_component_id');
    const hint = {} as HintButtonProps;
    const useHint = !!model.attributeDescription('report_component_id');
    if (useHint) {
        hint.title = resolvedLabel;
        hint.text = model.attributeDescription('report_component_id');
    }

    let isDisabled = readOnly;
    if (disabled !== undefined) {
        isDisabled = disabled;
    }

    const targetOptions = ReportComponentStore.getAll().filter(t => t.runPermitted).reduce((options: Group[], component) => {
        const target = component.report_target as ReportTargetModel;
        const groupName = [target.module_name, (target.ui_hints || {}).category, target.name].filter(s => s).join(' - ') || '';
        let group: Group | undefined = options.find((o: { label: string }) => o.label === groupName);
        if (!group) {
            group = {
                label: groupName,
                options: []
            };
            options.push(group);
        }
        group.options.push({label: component.name as string, value: component.getId()});
        group.options.sort((a, b) => a.label.localeCompare(b.label));
        return options;
    }, []);

    const onChange = (name: string | undefined, value: string) => {
        model.clearRunParams();
        model.handleSelectChange(name, value);
    }
    return (
        <SelectField
            name={'report_component_id'}
            label={resolvedLabel}
            value={model.viewModel.report_component_id}
            error={!!model.errors.report_component_id}
            helperText={model.errors.report_component_id}
            onChange={onChange}
            disabled={isDisabled}
            hint={useHint ? hint : undefined}
            options={targetOptions}
            {...props}
        />
    )
});