import * as React from 'react';
import {ParameterFieldProps} from "./ParameterFieldProps";
import {observer, Observer} from "mobx-react-lite";
import {CheckboxField, InputField, ReadonlyConsumer, useModelContext} from "@rx-suite/ui";
import {runInAction} from "mobx";
import {ReportComponentModel} from "../../../stores/ReportComponentStore";

export const GenericParameter: React.FunctionComponent<ParameterFieldProps> = observer(({parameter}) => {
    const component = useModelContext() as ReportComponentModel;
    const handleCheckboxChange = React.useCallback(e => {
        runInAction(() => {
            component.nestedAssignment(`parameters.${parameter.id}`, e.target.checked);
        });
    }, [parameter, component]);
    const handleInputChange = React.useCallback(e => {
        runInAction(() => {
            component.nestedAssignment(`parameters.${parameter.id}`, e.target.value);
        });
    }, [parameter, component]);
    switch (parameter.type) {
        case 'boolean':
            return <ReadonlyConsumer>
                {(readOnly: boolean) => (
                    <Observer>
                        {() => (
                            <CheckboxField label={parameter.name}
                                           checked={!!component.viewModel.parameters[parameter.id]}
                                           disabled={readOnly}
                                           onChange={handleCheckboxChange}/>
                        )}
                    </Observer>
                )}
            </ReadonlyConsumer>;
        case 'string':
            return <ReadonlyConsumer>
                {(readOnly: boolean) => (
                    <Observer>
                        {() => (
                            <InputField label={parameter.name}
                                           value={component.viewModel.parameters[parameter.id] || ''}
                                           disabled={readOnly}
                                           onChange={handleInputChange}/>
                        )}
                    </Observer>
                )}
            </ReadonlyConsumer>;
        default:
            //todo build a reasonable UI based on data type (string, number, etc.)
            return (
                <div>{JSON.stringify(parameter)}</div>
            )
    }
});