import * as React from 'react';
import {useCallback, useState} from 'react';
import {ParameterFieldProps} from "../ParameterFieldProps";
import {observer, Observer} from "mobx-react-lite";
import {t} from "@lingui/macro";
import {i18n, InputField, ReadonlyConsumer, useModelContext} from "@rx-suite/ui";
import {InputAdornment, List, Typography} from "@material-ui/core";
import {makeStyles} from "@material-ui/core/styles";
import {ReportTargetModel} from "../../../../stores/ReportTargetStore";
import {ColumnAdder} from "./column_parameter/ColumnAdder";
import {Search} from '@material-ui/icons';
import {ColumnDroppableList} from "./column_parameter/ColumnDroppableList";
import {ReportComponentModel} from "../../../../stores/ReportComponentStore";

const useStyles = makeStyles(theme => ({
    list: {
        display: 'flex',
        flexDirection: 'row',
        alignItems: 'stretch',
        height: '100%'
    },
    listParent: {
        overflowX: 'auto',
        flexGrow: 1
    },
    listDragOver: {
        background: theme.palette.success.light
    },
    item: {
        minWidth: 200,
        padding: theme.spacing(1),
        flexGrow: 1,
        height: '100%'
    },
    itemDrag: {
        background: theme.palette.info.light
    },
    picker: {
        height: 450,
        overflowY: 'auto',
        /*'&::-webkit-scrollbar': {
            width: 4
        },
        '&::-webkit-scrollbar-track': {
            '-webkit-box-shadow': 'inset 0 0 6px rgba(0,0,0,0.00)'
        },
        '&::-webkit-scrollbar-thumb': {
            backgroundColor: 'rgba(0,0,0,.1)',
            outline: '1px solid slategrey'
        }*/
    },
    frame: {
        display: 'flex',
        flexDirection: 'row',
        width: '100%'
    },
    adder: {
        minWidth: 300
    }
}));

export const ColumnParameter: React.FunctionComponent<ParameterFieldProps> = observer(() => {
    const component = useModelContext() as ReportComponentModel;
    const classes = useStyles();
    const target = component.viewModel.report_target as ReportTargetModel;
    const addButtonClick = useCallback((accessor: string) => {
        component.nestedAssignment('parameters.columns', [...(component.viewModel.parameters.columns || []), {accessor: accessor}]);
    }, [component]);
    const [search, setSearch] = useState('');
    const handleSearchChange = useCallback((e: React.ChangeEvent<HTMLInputElement | HTMLTextAreaElement>) => {
        setSearch(e.target.value);
    }, []);
    if (!target) {
        return null;
    }
    return (
        <ReadonlyConsumer>
            {(readOnly: boolean) => (
                <Observer>
                    {() => (
                        <>
                            <Typography variant={'h6'}>{i18n._(t`Columns`)}</Typography>
                            <div className={classes.frame}>
                                {!readOnly && <div className={classes.adder}>
                                    <InputField label={i18n._(t`Search`)} value={search} onChange={handleSearchChange}
                                                InputProps={{
                                                    startAdornment: (
                                                        <InputAdornment position="start">
                                                            <Search/>
                                                        </InputAdornment>
                                                    ),
                                                }}/>
                                    <List component={'div'} dense className={classes.picker}>
                                        {Object.entries(target.returns.properties).map(([key, def]: [string, any]) => (
                                            <ColumnAdder key={key} onAdd={addButtonClick}
                                                         accessor={key}
                                                         columnInfo={def}
                                                         search={search}/>
                                        ))}
                                    </List>
                                </div>}
                                <div className={classes.listParent}>
                                    {(component.viewModel.parameters.columns && component.viewModel.parameters.columns.length > 0)
                                        ? <ColumnDroppableList readOnly={readOnly}/>
                                        : i18n._(t`Add columns to show in the table...`)}
                                </div>
                            </div>
                        </>
                    )}
                </Observer>
            )}
        </ReadonlyConsumer>
    )
});