import * as React from 'react';
import {observer} from "mobx-react-lite";
import {ReportComponentModel} from "../../../../../stores/ReportComponentStore";
import {ColumnParameter} from "../../../../../stores/Types";
import {i18n, InputField, useModelContext} from "@rx-suite/ui";
import {InputFieldProps} from "@rx-suite/ui/build/components/base/InputField";
import {t} from "@lingui/macro";

type AggregationRounderProps = { item: ColumnParameter } & InputFieldProps;

export const AggregationRounderField: React.FunctionComponent<AggregationRounderProps> = observer(({item, ...inputProps}) => {
    const component = useModelContext() as ReportComponentModel;
    const handleChange = React.useCallback((e) => {
        component.setColumnProp(item, 'aggregation_options', {
            ...(item.aggregation_options || {}),
            pre_aggregation_rounding: e.target.value
        });
    }, [item]);
    const colDef = component.getReturnDef(item.accessor);
    if (colDef && colDef.format && colDef.format.decimals) {
        return <InputField type={'number'}
                           inputProps={{min: 0, max: colDef.format.decimals}}
                           label={i18n._(t`Aggregation Decimals`)}
                           onChange={handleChange}
                           value={(item.aggregation_options || {}).pre_aggregation_rounding || ''}
                           {...inputProps}/>
    } else {
        return null;
    }
});