import * as React from 'react';
import {useState} from 'react';
import {observer} from "mobx-react-lite";
import {Collapse, Divider, IconButton, List, ListItem, ListItemText} from "@material-ui/core";
import {Add, ExpandLess, ExpandMore} from "@material-ui/icons";
import {makeStyles} from "@material-ui/core/styles";
import classNames from 'classnames';
import {ColumnInfo} from '../../../../../stores/Types';
import {ColumnInfoButton} from "./ColumnInfoButton";
import {ReportTargetModel, ReportTargetStore} from "../../../../../stores/ReportTargetStore";
import {ReportComponentModel} from "../../../../../stores/ReportComponentStore";
import {useModelContext} from "@rx-suite/ui";

const useStyles = makeStyles(theme => ({
    pointer: {
        cursor: 'pointer'
    },
    nestList: {
        paddingLeft: '2em'
    },
    row: {
        '&:hover': {
            backgroundColor: 'rgba(0, 0, 0, 0.06)'
        }
    }
}));

type AdderProps = {
    onAdd: (accessor: string) => void,
    columnInfo: ColumnInfo,
    accessor: string,
    search?: string
}

export const ColumnAdder: React.FunctionComponent<AdderProps> = observer(({onAdd, columnInfo, accessor, search}) => {
    const component = useModelContext() as ReportComponentModel;
    const classes = useStyles();
    const expander = !!columnInfo.subdefinition;
    const [open, setOpen] = useState(false);
    const toggleOpen = React.useCallback(() => {
        setOpen(!open);
    }, [open]);
    const handleAdd = React.useCallback(() => {
        onAdd(accessor);
    }, [onAdd, accessor]);
    let descendentSearch = search;
    if (search && search !== '') {
        if (expander) {
            if ((columnInfo.name.toLowerCase().indexOf(search.toLowerCase()) !== -1) || (columnInfo.shortname && (columnInfo.shortname.toLowerCase().indexOf(search.toLowerCase()) !== -1))) {
                descendentSearch = '';
            }
        } else {
            if (!((columnInfo.name.toLowerCase().indexOf(search.toLowerCase()) !== -1) || (columnInfo.shortname && (columnInfo.shortname.toLowerCase().indexOf(search.toLowerCase()) !== -1)))) {
                return null;
            }
        }
    }
    if (columnInfo.subreportid && component.viewModel.report_target) {
        const parentTarget = (component.viewModel.report_target! as ReportTargetModel);
        const target = ReportTargetStore.getAll().find(t => {
            return t.module_id === parentTarget.module_id && t.report_id === columnInfo.subreportid
        });
        if (target && !target.designPermitted) {
            return null;
        }
    }
    return (
        <React.Fragment>
            <ListItem component={'div'} onClick={toggleOpen}
                      title={columnInfo.desc}
                      className={classNames(expander ? classes.pointer : false, classes.row)}>
                <ListItemText>{columnInfo.name}</ListItemText>
                <ColumnInfoButton columnInfo={columnInfo}/>
                {expander ?
                    <IconButton>{open ? <ExpandLess/> : <ExpandMore/>}</IconButton>
                    : <IconButton onClick={handleAdd}><Add/></IconButton>
                }
            </ListItem>
            {expander && <Collapse in={open}>
                <List component={'div'} dense disablePadding className={classes.nestList}>
                    {Object.entries(columnInfo.subdefinition!).map(([key, def]) => (
                        <ColumnAdder key={key} onAdd={onAdd} accessor={`${accessor}.${key}`} columnInfo={def}
                                     search={descendentSearch}/>
                    ))}
                </List>
            </Collapse>}
            <Divider/>
        </React.Fragment>
    )
});