import * as React from 'react';
import {observer} from "mobx-react-lite";
import {ReportComponentModel} from "../../../../../stores/ReportComponentStore";
import {ColumnAggregationOptions as aggType, ColumnParameter} from "../../../../../stores/Types";
import {ColumnSelect} from "./ColumnSelect";
import {AggregationRounderField} from "./AggregationRounderField";
import {t} from "@lingui/macro";
import {CheckboxField, i18n, ReadonlyConsumer, SelectField, useModelContext} from "@rx-suite/ui";

export const ColumnAggregationOptions: React.FunctionComponent<{ item: ColumnParameter }> = observer(({item}) => {
    const component = useModelContext() as ReportComponentModel;
    const aggregationInfo = component.aggregationDetails(item.aggregation);
    const handleComparisonColumnChange = React.useCallback((_name, value) => {
        component.setColumnProp(item, 'aggregation_options', {
            ...(item.aggregation_options || {}),
            comparison_column: value
        });
    }, [item]);
    const handleJoinColumnsChange = React.useCallback((_name, value) => {
        component.setColumnProp(item, 'aggregation_options', {
            ...(item.aggregation_options || {}),
            join_columns: value
        });
    }, [item]);
    const handleBlankIsZeroChanged = React.useCallback(e => {
        component.setColumnProp(item, 'aggregation_options', {
            ...(item.aggregation_options || {}),
            blank_is_zero: e.target.checked
        });
    }, [item]);
    const handleMetaAggregationChange = React.useCallback((_name, value) => {
        component.setColumnProp(item, 'aggregation_options', {
            ...(item.aggregation_options || {}),
            grand_total_meta_aggregator: value
        });
    }, [item]);

    if (!aggregationInfo || !aggregationInfo.aggregation_options || (Object.keys(aggregationInfo.aggregation_options).length === 0)) {
        return null;
    }
    return (
        <ReadonlyConsumer>
            {(readOnly: boolean) => (
                <React.Fragment>
                    {Object.entries(aggregationInfo.aggregation_options).map(([key, def]: [string, any]) => (
                        ({
                            comparison_column: <ColumnSelect key={key}
                                                             label={i18n._(t`Group Column`)}
                                                             disabled={readOnly}
                                                             onChange={handleComparisonColumnChange}
                                                             value={(item.aggregation_options || {}).comparison_column || ''}
                            />,
                            join_columns: <ColumnSelect key={key}
                                                        label={i18n._(t`Other Column(s)`)}
                                                        disabled={readOnly}
                                                        onChange={handleJoinColumnsChange}
                                                        filterOptions={([col, colDef]: [string, any]) => {
                                                            if (col === item.accessor) {
                                                                return false;
                                                            }
                                                            if(['date', 'time', 'datetime'].includes(colDef.type)){
                                                                return false;
                                                            }
                                                            return true;
                                                        }}
                                                        value={(item.aggregation_options || {}).join_columns || []}
                                                        multiple
                                                        clearable
                            />,
                            pre_aggregation_rounding: <AggregationRounderField key={key}
                                                                               disabled={readOnly} item={item}
                            />,
                            blank_is_zero: <CheckboxField checked={(item.aggregation_options || {}).blank_is_zero}
                                                          key={key}
                                                          label={i18n._(t`Blank is 0`)}
                                                          onChange={handleBlankIsZeroChanged}
                            />,
                            grand_total_meta_aggregator: component.hasGroupingColumn &&
                                <SelectField name={'meta_aggregation'}
                                             key={key}
                                             value={(item.aggregation_options || {}).grand_total_meta_aggregator || ''}
                                             label={i18n._(t`2nd-Level Aggregation`)}
                                             disabled={readOnly}
                                             options={
                                                 [{
                                                     label: i18n._(t`None`),
                                                     value: ''
                                                 },
                                                     ...component.aggregationOperationsForColumn(item.accessor, true).map((o: aggType) => ({
                                                         label: o.name,
                                                         value: o.id
                                                     }))
                                                 ]
                                             }
                                             onChange={handleMetaAggregationChange}
                                             clearable
                                />
                        } as { [s: string]: JSX.Element })[key] || null
                    ))}
                </React.Fragment>
            )}
        </ReadonlyConsumer>
    )
});