import * as React from 'react';
import {useCallback} from 'react';
import {observer, Observer} from "mobx-react-lite";
import {DragDropContext, Draggable, Droppable} from 'react-beautiful-dnd';
import {makeStyles} from "@material-ui/core/styles";
import classNames from 'classnames';
import {ColumnItem} from "./ColumnItem";
import {ReportTargetModel} from "../../../../../stores/ReportTargetStore";
import {ReportComponentModel} from "../../../../../stores/ReportComponentStore";
import {useModelContext} from "@rx-suite/ui";

const reorder = (list: any[], startIndex: number, endIndex: number) => {
    const result = Array.from(list);
    const [removed] = result.splice(startIndex, 1);
    result.splice(endIndex, 0, removed);
    return result;
};

const useStyles = makeStyles(theme => ({
    list: {
        display: 'inline-flex',
        flexDirection: 'row',
        alignItems: 'stretch',
        height: '100%',
        minWidth: 600
    },
    listDragOver: {
        background: theme.palette.success.light
    },
    item: {
        minWidth: '14em',
        padding: theme.spacing(1),
        flexGrow: 1,
        height: '100%'
    },
    itemDrag: {
        background: theme.palette.info.light
    },
}));

export const ColumnDroppableList: React.FunctionComponent<{ readOnly?: boolean }> = observer(({readOnly}) => {
    const component = useModelContext() as ReportComponentModel;
    const classes = useStyles();
    const onDragEnd = useCallback(result => {
        if (!result.destination) {
            return;
        }
        component.nestedAssignment('parameters.columns', reorder(
            component.viewModel.parameters.columns,
            result.source.index,
            result.destination.index
        ));
    }, [component]);
    const target = component.viewModel.report_target as ReportTargetModel;
    if (!target) {
        return null;
    }
    return (
        <DragDropContext onDragEnd={onDragEnd}>
            <Droppable droppableId="droppable" direction="horizontal"
                       isDropDisabled={readOnly}>
                {(provided, snapshot) => (
                    <Observer>
                        {() => (
                            <div ref={provided.innerRef} {...provided.droppableProps}
                                 className={classNames(
                                     classes.list,
                                     snapshot.isDraggingOver && classes.listDragOver
                                 )}>
                                {component.viewModel.parameters.columns.map((item: any, index: number) => (
                                    <Draggable
                                        isDragDisabled={readOnly}
                                        key={`${item.accessor}.${item.aggregation || index}`}
                                        draggableId={`${item.accessor}.${item.aggregation || index}`}
                                        index={index}>
                                        {(provided, snapshot) => (
                                            <Observer>
                                                {() => (
                                                    <div
                                                        ref={provided.innerRef}
                                                        {...provided.draggableProps}
                                                        {...provided.dragHandleProps}
                                                        className={classNames(
                                                            classes.item,
                                                            snapshot.isDragging && classes.itemDrag
                                                        )}
                                                        style={provided.draggableProps.style}>
                                                        <ColumnItem item={item}/>
                                                    </div>
                                                )}
                                            </Observer>
                                        )}
                                    </Draggable>
                                ))}
                                {provided.placeholder}
                            </div>
                        )}
                    </Observer>
                )}
            </Droppable>
        </DragDropContext>
    )
});