import * as React from 'react';
import {useCallback, useState} from 'react';
import {observer} from "mobx-react-lite";
import {IconButton, Popover} from "@material-ui/core";
import {Info} from "@material-ui/icons";
import {ColumnInfo} from '../../../../../stores/Types';
import {makeStyles} from "@material-ui/core/styles";

const useStyles = makeStyles(theme => ({
    info: {
        padding: theme.spacing(1),
        cursor: 'help',
        maxWidth: '400em'
    },
    button: {
        cursor: 'help'
    }
}));


type ColumnInfoButtonProps = {
    columnInfo: ColumnInfo
};

export const ColumnInfoButton: React.FunctionComponent<ColumnInfoButtonProps> = observer(({columnInfo}) => {
    const classes = useStyles();
    const [anchor, setAnchor] = useState(null);
    const open = !!anchor;
    const toggleMenu = useCallback(e => {
        setAnchor(anchor ? null : e.currentTarget);
        e.preventDefault();
        e.stopPropagation();
    }, [setAnchor]);
    const closeMenu = useCallback(() => {
        setAnchor(null);
    }, [setAnchor]);

    return (
        (columnInfo && columnInfo.desc) ? <React.Fragment>
            <IconButton onClick={toggleMenu} className={classes.button}><Info/></IconButton>
            <Popover anchorEl={anchor} open={open}
                     onClose={closeMenu}
                     anchorOrigin={{
                         vertical: 'top',
                         horizontal: 'left',
                     }}
                     transformOrigin={{
                         vertical: 'top',
                         horizontal: 'left',
                     }}
            >
                <div className={classes.info}><IconButton onClick={closeMenu}><Info
                    color={"secondary"}/></IconButton> {columnInfo.desc}</div>
            </Popover>
        </React.Fragment> : null
    );
});