import * as React from 'react';
import {observer} from "mobx-react-lite";
import {ReportComponentModel} from "../../../../../stores/ReportComponentStore";
import {ColumnInfo} from "../../../../../stores/Types";
import {SelectField, useModelContext} from "@rx-suite/ui";
import {ReportTargetModel} from "../../../../../stores/ReportTargetStore";
import {SelectFieldProps} from "@rx-suite/ui/build/components/base/SelectField";

type columnSelectProps = {
    filterOptions?: ([key, def]: [string, any]) => boolean
} & Omit<SelectFieldProps, 'options'>

const extractAccessors = (accumulated: { label: string, value: string }[], thisKey: string, thisDefinition: ColumnInfo, parentAccessor?: string, parentLabel?: string) => {
    if (thisDefinition.subdefinition) {
        Object.entries(thisDefinition.subdefinition).forEach(([key, subDef]) => extractAccessors(accumulated, key, subDef, thisKey, thisDefinition.name))
    } else {
        accumulated.push({
            label: (parentLabel ? `${parentLabel} / ` : '') + thisDefinition.name,
            value: (parentAccessor ? `${parentAccessor}.` : '') + thisKey
        });
    }
    return accumulated;
};

export const ColumnSelect: React.FunctionComponent<columnSelectProps> = observer(({filterOptions, ...selectProps}) => {
    const component = useModelContext() as ReportComponentModel;
    const target = component.viewModel.report_target as ReportTargetModel;
    if (!target) {
        return null;
    }
    let options = [] as { label: string, value: string }[];
    filterOptions = filterOptions || (() => true);
    const extractAccessors = (accumulated: { label: string, value: string }[], thisKey: string, thisDefinition: ColumnInfo, parentAccessor?: string, parentLabel?: string) => {
        if (thisDefinition.subdefinition) {
            Object.entries(thisDefinition.subdefinition).filter(filterOptions).forEach(([key, subDef]) => extractAccessors(accumulated, key, subDef, thisKey, thisDefinition.name))
        } else {
            accumulated.push({
                label: (parentLabel ? `${parentLabel} / ` : '') + thisDefinition.name,
                value: (parentAccessor ? `${parentAccessor}.` : '') + thisKey
            });
        }
        return accumulated;
    }
    Object.entries(target.returns.properties).filter(filterOptions).forEach(([key, def]: [string, any]) => extractAccessors(options, key, def));
    return <SelectField options={options} {...selectProps}/>
});