import * as React from 'react';
import {observer} from "mobx-react-lite";
import {PaddedPaper} from "@rx-suite/ui";
import {PDFTemplateStore} from "@rx-suite/stores";

type PrintWrapperProps = {
    template_id?: string,
    fontSize: number,
    applyPaper?: boolean
};

export const PrintWrapper: React.FunctionComponent<PrintWrapperProps> = observer(({
                                                                                      template_id,
                                                                                      fontSize,
                                                                                      applyPaper,
                                                                                      children
                                                                                  }) => {
    const template = PDFTemplateStore.get(template_id);
    const style = {fontSize: `${fontSize}px`} as any;
    if (!applyPaper || !template) {
        return <div style={style}>{children}</div>;
    }
    const unit = template.length_unit || 'px'
    style.margin = 'auto'
    style.boxSizing = 'border-box'
    if(template.landscape) {
        if (template.height) {
            style.width = `${template.height}${unit}`;
        }
        style.paddingLeft = `${(template.margin_top || 0)}${unit}`
        style.paddingRight = `${(template.margin_bottom || 0)}${unit}`
        style.paddingTop = `${(template.margin_left || 0)}${unit}`
        style.paddingBottom = `${(template.margin_right || 0)}${unit}`
    } else {
        if (template.width) {
            style.width = `${template.width}${unit}`;
        }
        style.paddingLeft = `${(template.margin_left || 0)}${unit}`
        style.paddingRight = `${(template.margin_right || 0)}${unit}`
        style.paddingTop = `${(template.margin_top || 0)}${unit}`
        style.paddingBottom = `${(template.margin_bottom || 0)}${unit}`
    }
    return <PaddedPaper style={style}>
        {children}
    </PaddedPaper>;
});