import * as React from 'react';
import {useEffect} from 'react';
import {observer} from "mobx-react-lite";
import {DateField, i18n, SelectField} from "@rx-suite/ui";
import {t} from "@lingui/macro";
import {Grid} from "@material-ui/core";
import {ReportTargetModel} from "../../../stores/ReportTargetStore";
import {PaginatedReportComponent} from "../../../stores/PaginatedReportComponent";

type ReportComponentDateRangePickerProps = {
    paginatedComponent: PaginatedReportComponent
};

export const ReportComponentDateRangePicker: React.FunctionComponent<ReportComponentDateRangePickerProps> = observer(({
                                                                                                                          paginatedComponent
                                                                                                                      }) => {
    useEffect(() => {
        const validOptions = Object.keys(paginatedComponent.component.supportedDateRangeColumns);
        if (!validOptions.find(o => o === paginatedComponent.dateColumn)) {
            const defaultDate = validOptions.find(o => o === ((paginatedComponent.component.viewModel.report_target as ReportTargetModel || {}).ui_hints || {}).default_date) || validOptions[0];
            paginatedComponent.setDateColumn(defaultDate);
        }
    }, [paginatedComponent, paginatedComponent.component.report_target]);
    if (!paginatedComponent.component || !paginatedComponent.component.viewModel.report_target_id || !paginatedComponent.component.supportedDateRangeColumns || !Object.keys(paginatedComponent.component.supportedDateRangeColumns).length) {
        return null;
    }
    return <Grid container justify={"space-between"} alignItems={"flex-end"}>
        <Grid item md={4} xs={12}>
            <SelectField label={i18n._(t`Date Type`)}
                         onChange={(_, val) => paginatedComponent.setDateColumn(val)}
                         value={paginatedComponent.viewModel.dateColumn || ''}
                         error={!!paginatedComponent.dateColumnError}
                         options={Object.entries(paginatedComponent.component.supportedDateRangeColumns).map(([key, c]: [string, any]) => ({
                             value: key,
                             label: c.name
                         }))}/>
        </Grid>
        <Grid item md={2} xs={12}>
            <SelectField label={i18n._(t`Range`)}
                         onChange={(_, newRange) => paginatedComponent.setDateRange(newRange)}
                         options={paginatedComponent.dateRanges}
                         value={paginatedComponent.currentDateRangeValue}
            />
        </Grid>
        <Grid item md={3} xs={12}>
            <DateField label={i18n._(t`Start Date`)}
                       timeFormat={paginatedComponent.selectedDateUsesTime ? 'HH:mm:ss' : false}
                       dateFormat={'YYYY-MM-DD'}
                       onChange={paginatedComponent.setStartDate}
                       value={paginatedComponent.viewModel.startDate || ''}
                       error={paginatedComponent.startDateError}
                       strictParsing={false}
                       closeOnSelect/>
        </Grid>
        <Grid item md={3} xs={12}>
            <DateField label={i18n._(t`End Date`)}
                       timeFormat={paginatedComponent.selectedDateUsesTime ? 'HH:mm:ss' : false}
                       dateFormat={'YYYY-MM-DD'}
                       onChange={paginatedComponent.setEndDate}
                       value={paginatedComponent.viewModel.endDate || ''}
                       error={paginatedComponent.endDateError}
                       strictParsing={false}
                       closeOnSelect
                       hint={{
                           title: i18n._(t`Date Range`),
                           text: i18n._(t`Set the date range for the report.`),
                       }}
            />
        </Grid>
    </Grid>;
});