import * as React from 'react';
import {observer} from "mobx-react-lite";
import {PaginatedReportComponent} from "../../../stores/PaginatedReportComponent";
import {i18n, SelectField} from "@rx-suite/ui";
import {ReportTargetModel} from "../../../stores/ReportTargetStore";
import {t, Trans} from "@lingui/macro";

type ReportComponentRunParamsProps = {
    paginatedComponent: PaginatedReportComponent,
    column: string
};

export const ReportComponentRunParam: React.FunctionComponent<ReportComponentRunParamsProps> = observer(({
                                                                                                             paginatedComponent,
                                                                                                             column
                                                                                                         }) => {
    const [knownValues, setKnownValues] = React.useState<string[]>([]);
    const [loading, setLoading] = React.useState(false);
    React.useEffect(() => {
        let isSubscribed = true;
        setLoading(true);
        if (paginatedComponent.component.viewModel.report_target) {
            (paginatedComponent.component.viewModel.report_target as ReportTargetModel).runFilterOptions(column).then(values => {
                if (isSubscribed) {
                    setLoading(false);
                    setKnownValues(values);
                }
            });
        }
        return () => {
            isSubscribed = false;
        };
    }, [paginatedComponent.component.viewModel.report_target, column]);
    const columnDefinition = paginatedComponent.component.getReturnDef(column);
    if (!columnDefinition) {
        return null;
    }

    const options = [...knownValues.map(v => ({
        label: v,
        value: v
    })), {
        label: i18n._(t`[Blank]`),
        value: ''
    }, ...(paginatedComponent.runFilterValue(column) || []).map(v => ({
        label: v,
        value: v
    }))];
    return <SelectField label={columnDefinition.name}
                        options={options}
                        name={column}
                        value={paginatedComponent.runFilterValue(column) || []}
                        onChange={paginatedComponent.handleRunFilterChange}
                        loading={loading}
                        hint={{
                            title: columnDefinition.name,
                            subtitle: i18n._(t`Run Filter`),
                            children: <div>
                                <div>{columnDefinition.desc}</div>
                                <Trans>You can add an option to the list by typing it, even if it doesn't show up in the
                                    dropdown.</Trans>
                            </div>
                        }}
                        multiple
                        creatable
                        clearable
    />
});