import * as React from 'react';
import {observer} from "mobx-react-lite";
import {PaginatedReportComponent} from "../../../../stores/PaginatedReportComponent";
import {t} from "@lingui/macro";
import moment from "moment";
import {LinearProgress} from "@material-ui/core";
import {i18n} from "@rx-suite/ui";

type LiveTableFooterProps = {
    children: React.ReactNode,
    paginatedComponent: PaginatedReportComponent,
    needFooter: boolean
}

export const LiveTableFooter: React.FunctionComponent<LiveTableFooterProps> = observer(({
                                                                                            children,
                                                                                            paginatedComponent,
                                                                                            needFooter
                                                                                        }) => {
    React.useEffect(() => {
        if (paginatedComponent.hasRunTotals) {
            paginatedComponent.flagRenderedTotals();
        }
    }, [paginatedComponent, paginatedComponent.hasRunTotals])

    if (needFooter) {
        if (paginatedComponent.totalsFetchError) {
            return <div>
                <div>{i18n._(t`There was an error and the report could not be generated.  Please provide the following info to support:`)}</div>
                <div>{paginatedComponent.runLink}</div>
                <div>{moment().toString()}</div>
                <div>{paginatedComponent.totalsFetchError}</div>
            </div>;
        } else {
            if (paginatedComponent.hasRunTotals) {
                return <div className={'rt-thead'}>
                    {children}
                </div>;
            } else {
                return <LinearProgress/>;
            }
        }
    } else {
        return null;
    }
});
