import * as React from 'react';
import {observer} from "mobx-react-lite";
import {makeStyles} from "@material-ui/core/styles";
import {RxAppModel, RxAppStore} from "@rx-suite/stores";
import classNames from 'classnames';

type LiveTableHeaderProps = {
    children: React.ReactNode,
    className?: string
}

const useStyles = makeStyles(theme => ({
    // show on each print page
    printableHeader: {
        display: 'table-header-group!important' as any,
        breakInside: 'avoid!important' as any,
        pageBreakInside: 'avoid!important' as any,
        borderWidth: '0px!important',
        borderBottomWidth: '1px!important',
        borderStyle: 'solid',
        borderColor: `${theme.palette.grey[300]}!important`,
    },
    webHeader: {
        position: 'sticky!important' as any,
        top: '64px!important', // app bar height
        backgroundColor: "#FFF",
        zIndex: 1500
    }
}));

export const LiveTableHeader: React.FunctionComponent<LiveTableHeaderProps> = observer(({
                                                                                            children,
                                                                                            className
                                                                                        }) => {
    const classes = useStyles();
    const appUI = RxAppStore.selectedModel as RxAppModel;
    const printView = appUI && appUI.isPrintView;
    return <div className={classNames('rt-thead',
        printView ? classes.printableHeader : classes.webHeader,
        className)}>
        {children}
    </div>;
});
