import * as React from 'react';
import {observer} from "mobx-react-lite";
import {ButtonField, i18n, PaddedPaper} from "@rx-suite/ui/build";
import {t} from "@lingui/macro";
import {Popover, Tooltip, Typography} from "@material-ui/core";
import {Link} from "@material-ui/icons";
import copy from "clipboard-copy"
import {PaginatedReportComponent} from "../../../../stores/PaginatedReportComponent";

export const CopyToClipboardButton: React.FunctionComponent<{ paginatedComponent: PaginatedReportComponent }> = observer(({paginatedComponent}) => {
    const [anchor, setAnchor] = React.useState(null);
    const open = !!anchor;
    const copyClick = React.useCallback(e => {
        copy(paginatedComponent.runLink);
        setAnchor(anchor ? null : e.currentTarget);
    }, [anchor, setAnchor, paginatedComponent]);
    const closePopup = React.useCallback(e => {
        setAnchor(null);
    }, [setAnchor]);
    const disabled = paginatedComponent.component.isNew || paginatedComponent.component.viewModel.isDirty;
    return (
        <React.Fragment>
            <Tooltip
                disableFocusListener disableTouchListener
                title={disabled ? i18n._(t`You need to save your changes to copy this link`) : i18n._(t`Get a link that lets you run this report with these settings`)}>
                <div style={{display: 'inline-block'}}>
                    <ButtonField text={i18n._(t`Copy Run Link`)}
                                 startIcon={<Link/>}
                                 disabled={disabled}
                                 onClick={copyClick}/>
                </div>
            </Tooltip>
            <Popover anchorEl={anchor} open={open}
                     onClose={closePopup}
                     anchorOrigin={{
                         vertical: 'bottom',
                         horizontal: 'center',
                     }}
                     transformOrigin={{
                         vertical: 'top',
                         horizontal: 'center',
                     }}
            >
                <PaddedPaper>
                    <Typography variant={'caption'}>{i18n._(t`Copied to clipboard!`)}</Typography>
                </PaddedPaper>
            </Popover>
        </React.Fragment>
    )
});
