import * as React from 'react';
import {observer} from "mobx-react-lite";
import {MakePDFField} from "@rx-suite/ui";
import {PaginatedReportComponent} from "../../../../stores/PaginatedReportComponent";
import {ReportTargetModel} from "../../../../stores/ReportTargetStore";
import {makeStyles} from "@material-ui/core/styles";

const useStyles = makeStyles(theme => ({
    pdf: {
        marginLeft: theme.spacing(1),
        minWidth: '20em'
    }
}));

type PDFButtonProps = {
    paginatedComponent: PaginatedReportComponent,
    template_id?: string,
    onTemplateIdChange?: (newId:string) => void
};

export const PDFButton: React.FunctionComponent<PDFButtonProps> = observer(({paginatedComponent,template_id,onTemplateIdChange}) => {
    const classes = useStyles();
    const target = paginatedComponent.component.viewModel.report_target as ReportTargetModel;
    return (
        <div className={classes.pdf}>
            <MakePDFField sources={paginatedComponent.getSourceUrls}
                          pdfName={paginatedComponent.component.viewModel.name}
                          local_storage={[{
                              name: 'componentOverride',
                              value: JSON.stringify({
                                  ...paginatedComponent.component.viewModel.asJson,
                                  parameters: JSON.stringify(paginatedComponent.component.printParameters)
                              })
                          },{
                              name: 'componentFontSize',
                              value: paginatedComponent.fontSize.toString()
                          },{
                              name: 'componentResizings',
                              value: JSON.stringify(paginatedComponent.resizings)
                          }
                          ]}
                          template_id={template_id}
                          onTemplateIdChange={onTemplateIdChange}
                          notes={paginatedComponent.component.viewModel.desc} target_id={target.report_id}
                          action_id={'run'}
                          module_id={target.module_id}/>
        </div>

    )
});
