import * as React from 'react';
import {BreadModel, i18n, makeColumn} from "@rx-suite/ui";
import {AutomaticReportsForm} from "./AutomaticReportsForm";
import {t} from "@lingui/macro";
import {AutomaticReportModel, AutomaticReportStore} from "../../stores/AutomaticReportStore";
import {Observer} from "mobx-react-lite";

export const AutomaticReportsBreadModel = () => {
    const columns = React.useMemo(() => {
        return [
            makeColumn('name', i18n._(t`Name`), "string"),
            makeColumn('report_component.name', i18n._(t`Report`), "string"),
            {
                Header: i18n._(t`Run Every`),
                id: 'runEvery',
                accessor: (model: AutomaticReportModel) => model,
                Cell: (row: { original: AutomaticReportModel | null | undefined }) => <Observer>
                    {() => <>
                        {row.original ?
                            <div>
                                {row.original.friendlyRunFrequency}
                            </div>
                            : null
                        }
                    </>}
                </Observer>,
                filterable: false,
                sortable: false
            },
            {
                Header: i18n._(t`Capture`),
                id: 'period',
                accessor: (model: AutomaticReportModel) => model,
                Cell: (row: { original: AutomaticReportModel | null | undefined }) => <Observer>
                    {() => <>
                        {row.original ?
                            <div>
                                {row.original.friendlyRunPeriod}
                            </div>
                            : null
                        }
                    </>}
                </Observer>,
                filterable: false,
                sortable: false
            }
        ]

    }, []);
    return (
        <BreadModel Form={AutomaticReportsForm} store={AutomaticReportStore} columns={columns}/>
    )
};
