import * as React from 'react';
import {BreadModel} from "@rx-suite/ui";
import {ReportComponentResultModel, ReportComponentResultStore} from "../../stores/ReportComponentResultStore";
import {ReportComponentResultForm} from "./ReportComponentResultForm";
import {i18n, makeColumn} from "@rx-suite/ui/build";
import {t} from "@lingui/macro";
import {Model} from "@rx-suite/data/build";
import {ReportComponentResultStatus} from "../../components/report_component_results/ReportComponentResultStatus";
import {ReportComponentResultDownloadButton} from "../../components/report_component_results/ReportComponentResultDownloadButton";

export const ReportComponentResultBreadModel = () => {
    const actions = React.useCallback((mod: Model) => {
        return <ReportComponentResultDownloadButton result={mod as ReportComponentResultModel}/>
    }, []);
    const columns = React.useMemo(() => {
        return [
            makeColumn('created_at', i18n._(t`Created`), "date"),
            makeColumn('name', i18n._(t`Name`), "string"),
            makeColumn('report_target.name', i18n._(t`Target`), "string"),
            makeColumn('desc', i18n._(t`Description`), "string"),
            {
                Header: i18n._(t`Status`),
                accessor: (d: unknown) => d as ReportComponentResultModel,
                id: 'generating',
                style: {textAlign: "center"},
                width: 200,
                Cell: (cellInfo: { value: ReportComponentResultModel }) => {
                    if (!cellInfo.value || !cellInfo.value.getId) {
                        return null;
                    }
                    return <ReportComponentResultStatus result={cellInfo.value}/>
                },
                sortable: false,
                filterable: false
            }
        ]

    }, []);
    return (
        <BreadModel Form={ReportComponentResultForm} store={ReportComponentResultStore} columns={columns}
                    tableProps={{customActions: actions, defaultSorted: [{id: 'created_at', desc: true}]}}/>
    )
};
