import * as React from 'react';
import {BreadModel, i18n, makeColumn} from "@rx-suite/ui";
import {ReportComponentStore} from "../../stores/ReportComponentStore";
import {ReportComponentForm} from "./ReportComponentForm";
import {t} from "@lingui/macro";
import {featureEnabled} from "@rx-suite/stores";
import {observer, Observer} from "mobx-react-lite";
import {Model} from "@rx-suite/data";

export const ReportComponentBreadModel = observer(() => {
    const columns = [
        makeColumn('name', i18n._(t`Name`), "string"),
        {
            Header: i18n._(t`Target`),
            id: 'report_target.name',
            accessor: (model: Model) => model,
            Cell: (row: { original: Model | null | undefined }) => {
                return (
                    <Observer>
                        {
                            () => {
                                let value = null;
                                if (row.original) {
                                    value = row.original.dig('report_target.name');
                                }
                                return (
                                    <span title={value}>
                                    {value}
                                </span>
                                )
                            }
                        }
                    </Observer>
                )
            },
            filterable: true,
            sortable: true
        },
        {
            Header: i18n._(t`Module`),
            id: 'report_target.module_name',
            accessor: (model: Model) => model,
            Cell: (row: { original: Model | null | undefined }) => {
                return (
                    <Observer>
                        {
                            () => {
                                let value = null;
                                if (row.original) {
                                    value = row.original.dig('report_target.module_name');
                                }
                                return (
                                    <span title={value}>
                                    {value}
                                </span>
                                )
                            }
                        }
                    </Observer>
                )
            },
            filterable: true,
            sortable: true
        },
        makeColumn('desc', i18n._(t`Description`), "string", val => {
            return (val || '').split("\n").map((v: string) => <React.Fragment key={v}>{v}<br/></React.Fragment>)
        })
    ];
    const tableProps = {
        showCreateButton: featureEnabled('designer'),
        preferReadLink: true
    };
    return (
        <BreadModel store={ReportComponentStore} Form={ReportComponentForm} columns={columns} tableProps={tableProps}/>
    )
});