import * as React from 'react';
import {observer} from "mobx-react-lite";
import {FormProps, ModelForm, ModelInput, ModelSelect} from "@rx-suite/ui";
import {ReportTargetStore} from '../../stores/ReportTargetStore'
import {ParameterForm} from "../../components/report_components/parameter_fields/ParameterForm";
import {ReportComponentModel} from "../../stores/ReportComponentStore";
import {reaction, runInAction} from "mobx";
import {UIHints} from "../../stores/Types";

type Option = { label: string, value: string, isDisabled?: boolean };
type Group = { label: string, options: Option[] };

type ComponentBuilderProps = {
    model: ReportComponentModel
} & Omit<FormProps, 'model'>

export const ReportComponentBuilder: React.FunctionComponent<ComponentBuilderProps> = observer(({model, readOnly}) => {
    React.useEffect(
        () => reaction(() => model.viewModel.report_target_id, () => runInAction(() => model.viewModel.parameters = {})),
        [model]
    );

    const targetOptions = ReportTargetStore.getAll().reduce((options: Group[], target) => {
        let groupName = '';
        if (target.module_name && (target.ui_hints as UIHints)?.category) {
            groupName = `${target.module_name} - ${(target.ui_hints as UIHints).category}`
        } else {
            groupName = (target.module_name || '') as string
        }
        let group: Group | undefined = options.find((o: { label: string }) => o.label === groupName);
        if (!group) {
            group = {
                label: groupName,
                options: []
            };
            options.push(group);
        }
        const isDisabled = !target.designPermitted;
        group.options.push({label: target.name as string, value: target.getId(), isDisabled: isDisabled});
        group.options.sort((a, b) => a.label.localeCompare(b.label));
        return options
    }, []).sort((a, b) => {
        return a.label.localeCompare(b.label);
    });

    return (
        <ModelForm model={model} readOnly={readOnly || !model.designPermitted} suppressWrapper>
            <ModelInput name={"name"}/>
            <ModelInput name={"desc"} multiline rowsMax={4}/>
            <ModelSelect label={model.label('report_target_id')}
                         name={"report_target_id"}
                         options={targetOptions}/>
            {(model.viewModel.report_target_id || (model.viewModel.report_target_id === 0)) ? <ParameterForm/> : null}
        </ModelForm>
    )
});
