import {dataStorePermission, i18n, RouteDefinition} from "@rx-suite/ui";
import {Assignment, PictureAsPdf, Schedule} from '@material-ui/icons';
import {ReportComponentStore} from "./stores/ReportComponentStore";
import {ReportComponentBreadModel} from "./pages/report_components/ReportComponentBreadModel";
import {ReportComponentResultStore} from "./stores/ReportComponentResultStore";
import {ReportComponentResultBreadModel} from "./pages/report_component_results/ReportComponentResultBreadModel";
import {t} from "@lingui/macro";
import {CSVIcon} from "./components/routes/CSVIcon";
import {AutomaticReportStore} from "./stores/AutomaticReportStore";
import {AutomaticReportsBreadModel} from "./pages/automatic_reports/AutomaticReportsBreadModel";

export const routes: RouteDefinition[] = [
    {
        label: i18n._(t`Run Reports`),
        to: "/report_components",
        help: i18n._(t`View report data in your browser, or export it to another format.`),
        exact: false,
        permission: dataStorePermission(ReportComponentStore),
        Component: ReportComponentBreadModel,
        Icon: Assignment
    },
    {
        label: i18n._(t`Schedule Reports`),
        to: "/automatic_reports",
        help: i18n._(t`Schedule Reports to run periodically`),
        exact: false,
        permission: dataStorePermission(AutomaticReportStore),
        Component: AutomaticReportsBreadModel,
        Icon: Schedule
    },
    {
        label: i18n._(t`CSV Exports`),
        to: "/report_component_results",
        help: i18n._(t`View previously exported report data`),
        exact: false,
        permission: dataStorePermission(ReportComponentResultStore),
        Component: ReportComponentResultBreadModel,
        Icon: CSVIcon
    },
    {
        label: i18n._(t`PDF Exports`),
        to: 'results',
        exact: true,
        Icon: PictureAsPdf,
        module: 'rx_pdf'
    }
];