# == Schema Information
#
# Table name: report_targets
#
#  id            :bigint           not null, primary key
#  desc          :string
#  module_name   :string
#  name          :string
#  parameters    :string
#  returns       :string
#  ui_hints      :string
#  created_at    :datetime         not null
#  updated_at    :datetime         not null
#  module_id     :string
#  permission_id :string
#  report_id     :string
#
class ReportTarget < ApplicationRecord
  def self.display_name
    'Report Target'
  end

  def run(parameters)
    RxModule::Communicator.call_module_method(module_id, "/api/rx_module/reports/#{report_id}", :post, parameters) do |req|
      req.options[:open_timeout] = 10
      req.options[:timeout] = 180
    end
  end

  def paged_run(parameters, batch_size = 500)
    offset = 0
    parameters['skip_record_count'] = false
    loop do
      resp = run((parameters || {}).merge(pagination: {limit: batch_size, offset: offset}))
      if (yield resp) || (resp[:hits].length == 0)
        break
      end
      offset += resp[:hits].length
      parameters['skip_record_count'] = true
    end
  end

  def should_broadcast?
    false # can cause the relevant components to flash; updates much less often than the routine runs & never updates manually
  end

  def display_name(accessor)
    path = accessor.split('.')
    obj = JSON.parse(returns || '')&.[]('properties')
    while obj && (step = path.shift)
      obj = obj[step]
      obj = obj&.[]('subdefinition') if obj&.[]('subdefinition')
    end
    obj&.[]('name')
  end

  def build_run_param_cache!
    ui_hints_parsed = JSON.parse(ui_hints || '{}')
    if ui_hints_parsed && ui_hints_parsed.is_a?(Hash) && ui_hints_parsed['runner_params']
      ui_hints_parsed['runner_params'].each do |col|
        begin
          Rails.logger.debug { {msg: 'Building run cache', column: col, target: self} }
          known_filter_vals(col)
        rescue StandardError => err
          Rails.logger.warn { {msg: 'Failed to build run cache', column: col, target: self} }
        end
      end
    end
  end

  def known_filter_vals(column)
    cache_key = "#{id}.#{column}"
    Rails.cache.fetch(cache_key, expires_in: (23.hours + 55.minutes)) do
      Rails.logger.debug { {msg: 'Run cache miss', cache_key: cache_key, target: self} }
      RxModule::Communicator.call_module_method(module_id, "/api/rx_module/reports/#{report_id}/#{column.gsub('.', '-')}/values", :get)
    end
  end
end
