class AutomaticReportRoutine < RxModule::Routine
  class << self
    # report_id => rufus_id
    def report_jobs
      @_jobs ||= {}
    end

    def set_next_run(report)
      begin
        report.reload
        report.set_next_run!
        job = get_job!(report)
        next_run = report.computed_next_run
        if job.next_time && next_run && (job.next_time > next_run + 2.minutes)
          Rails.logger.info({action: "Updated scheduled report time to #{next_run}", report: report.as_json})
          job.next_time = EtOrbi.make_time(next_run)
        end
      rescue StandardError => err
        report.update(last_run_error: err.message)
        Rails.logger.error { {msg: 'Automatic report failed to schedule', report: report&.as_json} }
      end
    end

    def get_job!(report)
      job = get_job(report)
      unless job
        run_time = report.computed_next_run
        Rails.logger.info({action: "Scheduled report for #{run_time}", report: report.as_json})
        job_id = Rufus::Scheduler.s.at(run_time) do |rufus_job|
          ActiveRecord::Base.connection_pool.with_connection do
            report.reload
            run_time = rufus_job.time
            Rails.logger.info({action: "Running scheduled report for #{run_time}", report: report.as_json})
            report.generate(run_time)
          end
        end
        report_jobs[report.id] = job_id
        job = Rufus::Scheduler.s.job(job_id)
      end
      job
    end

    def get_job(report)
      Rufus::Scheduler.s.job(report_jobs[report.respond_to?(:id) ? report.id : report])
    end

    def clear_job(id)
      if (job = get_job(id))
        begin
          report_jobs.delete(id)
          job.unschedule
          job.kill
        rescue StandardError => e
          # The scheduler purposely raises an exception to kill
        end
      end
    end

    def clear_deleted_jobs(reports_to_keep)
      ids_to_keep = reports_to_keep.map { |c| c[:id] }
      report_jobs.keep_if do |report_id, _rufus_id|
        begin
          if ids_to_keep.include?(report_id)
            true
          else
            clear_job(report_id)
            false
          end
        rescue StandardError
          Rails.logger.warn { "Job failed to delete" }
          true
        end
      end
    end

    def frequency
      "1m"
    end

    def work
      reports = AutomaticReport.all
      clear_deleted_jobs(reports)
      reports.each do |c|
        set_next_run(c)
      end
    end
  end
end