class UpdateReportDefinitions < RxModule::Routine
  class << self
    def frequency
      '1m'
    end

    def work
      RxModule::Communicator::Hub.list_modules.each do |mod|
        begin
          if mod[:type] == 'RxModuleComponent'
            targets_to_keep = []
            Rails.logger.debug { {msg: "Checking Module Report Definitions", module: mod} }
            RxModule::Communicator.call_module_method(mod[:module_id], '/api/rx_module/reports', :get).each do |report_def|
              dirty = false
              target = ReportTarget.where(module_id: mod[:module_id], report_id: report_def[:id]).first_or_create do
                dirty = true # block is only yielded if create is called
              end
              [:module_name].each do |k|
                if target[k] != mod[k]
                  dirty = true
                  target[k] = mod[k]
                end
              end
              [:name, :desc, :permission_id].each do |k|
                if target[k] != report_def[k]
                  dirty = true
                  target[k] = report_def[k]
                end
              end
              [:ui_hints, :parameters, :returns].each do |k|
                if target[k] != report_def[k].to_json
                  dirty = true
                  target[k] = report_def[k].to_json
                end
              end
              target.save if dirty
              targets_to_keep << target.id
            end
            ReportTarget.where.not(id: targets_to_keep).where(module_id: mod[:module_id]).destroy_all
          end
        rescue StandardError
          Rails.logger.debug { {msg: "Module is not responding to report definition request", module: mod} }
        end
        begin
          if mod[:type] == 'RxModuleComponent'
            canned_reports_to_keep = []
            RxModule::Communicator.call_module_method(mod[:module_id], '/api/rx_module/canned_reports', :get).each do |report_def|
              dirty = false
              report = ReportComponent.joins(:report_target).where(canned_report_id: report_def[:canned_report_id], report_targets: {module_id: mod[:module_id], report_id: report_def[:report_target][:report_id]}).first_or_create do
                dirty = true # block is only yielded if create is called
              end
              [:name, :desc, :parameters, :canned_report_id].each do |k|
                if report[k] != report_def[k]
                  dirty = true
                  report[k] = report_def[k]
                end
              end
              if dirty
                report.report_target = ReportTarget.where({module_id: mod[:module_id], report_id: report_def[:report_target][:report_id]}).first
                report.save
              end
              canned_reports_to_keep << report.id
            end
            ReportComponent.joins(:report_target).where.not(id: canned_reports_to_keep).where.not(canned_report_id: nil).where(report_targets: {module_id: mod[:module_id]}).destroy_all
          end
        rescue StandardError
          Rails.logger.debug { {module: mod, msg: "Module is not responding to canned report definition request"} }
        end
      end
    end
  end
end